# Roles and Areas of Responsibility

The following is a non-exhaustive list of the primary contributors to `graspologic` and 
their roles and areas of responsibilities. Please feel free to use this list to `@` 
specific contributors in your issues or pull requests that seem to line up best with 
your issue! 

## Core Contributors

### Ali Saad-Eldin ([@asaadeldin11](https://github.com/asaadeldin11)) (he/him)
Ali is a Masters Student at Johns Hopkins University. He contributes and reviews code 
mostly for the `match` and `embed` modules. 

### Anton Alyakin ([@alyakin314](https://github.com/alyakin314))
Anton is an Assistant Research Engineer at Johns Hopkins University. His primary 
contributions to `graspologic` are within `align` and `inference` modules. Ask him 
anything about those.

### Benjamin Pedigo ([@bdpedigo](https://github.com/bdpedigo)) (he/him)
Ben is a PhD student at Johns Hopkins University in the NeuroData lab. Ask Ben about 
network model fitting and sampling, clustering, and spectral embedding (`models`, 
`simulations`, `cluster`, and `embed`, respectfully). Ben is also happy to hear how we 
can improve our tutorials.

### Carolyn Buractaon ([@carolyncb](https://github.com/carolyncb)) (she/her)
Carolyn is a Technical Program Manager at Microsoft. Ask Carolyn about where the project
is going and how it’s organized.

### Dwayne Pryce ([@dwaynepryce](https://github.com/dwaynepryce)) (he/him)
Dwayne Pryce is a Software Engineer at Microsoft Research. His primary contributions to
`graspologic` are on the steering committee, quality of life utility functions, and
build and release processes.

### Jaewon Chung ([@j1c](https://github.com/j1c)) (he/him)
Jaewon is a PhD student at Johns Hopkins University. He is a maintainer and developer 
for `graspologic`, and is responsible for reviewing code contributions, merging pull 
requests, and making decisions on the `graspologic` API.

### Nick Caurvina ([@nyecarr](https://github.com/nyecarr)) (he/him)
Nick is a Software Engineer at Microsoft Research. Ask Nick about the network 
embeddings and their application to business problems.
